@@ -9,8 +9,8 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
-// ShowFlags returns the flags for the show command. Exported to re-use in main
-// for the default command.
+// ShowFlags returns the flags for the show command.
+// Exported to re-use in main for the default command.
 func ShowFlags() []cli.Flag {
 	return []cli.Flag{
 		&cli.BoolFlag{
@@ -68,6 +68,7 @@ func ShowFlags() []cli.Flag {
 }
 
 // GetCommands returns the cli commands exported by this module.
+// It also includes any commands provided by the crypto and storage backends.
 func (s *Action) GetCommands() []*cli.Command {
 	cmds := []*cli.Command{
 		{
@@ -222,6 +223,16 @@ func (s *Action) GetCommands() []*cli.Command {
 					Aliases: []string{"f"},
 					Usage:   "Force to copy the secret and overwrite existing one",
 				},
+				&cli.StringFlag{
+					Name:    "commit-message",
+					Aliases: []string{"m"},
+					Usage:   "Set the commit message",
+				},
+				&cli.BoolFlag{
+					Name:    "interactive-commit",
+					Aliases: []string{"i"},
+					Usage:   "Open an editor for the commit message",
+				},
 			},
 		},
 		{
@@ -268,6 +279,16 @@ func (s *Action) GetCommands() []*cli.Command {
 					Aliases: []string{"f"},
 					Usage:   "Force to delete the secret",
 				},
+				&cli.StringFlag{
+					Name:    "commit-message",
+					Aliases: []string{"m"},
+					Usage:   "Set the commit message",
+				},
+				&cli.BoolFlag{
+					Name:    "interactive-commit",
+					Aliases: []string{"i"},
+					Usage:   "Open an editor for the commit message",
+				},
 			},
 		},
 		{
@@ -298,6 +319,16 @@ func (s *Action) GetCommands() []*cli.Command {
 					Aliases: []string{"c"},
 					Usage:   "Create a new secret if none found",
 				},
+				&cli.StringFlag{
+					Name:    "commit-message",
+					Aliases: []string{"m"},
+					Usage:   "Set the commit message",
+				},
+				&cli.BoolFlag{
+					Name:    "interactive-commit",
+					Aliases: []string{"i"},
+					Usage:   "Open an editor for the commit message",
+				},
 			},
 		},
 		{
@@ -308,7 +339,6 @@ func (s *Action) GetCommands() []*cli.Command {
 			Before:       s.IsInitialized,
 			Action:       s.Env,
 			BashComplete: s.Complete,
-			Hidden:       true,
 			Flags: []cli.Flag{
 				&cli.BoolFlag{
 					Name:    "keep-case",
@@ -456,6 +486,16 @@ func (s *Action) GetCommands() []*cli.Command {
 					Usage:   "Language to generate password from, currently only en (english, default) or de are supported",
 					Value:   "en",
 				},
+				&cli.StringFlag{
+					Name:    "commit-message",
+					Aliases: []string{"m"},
+					Usage:   "Set the commit message",
+				},
+				&cli.BoolFlag{
+					Name:    "interactive-commit",
+					Aliases: []string{"i"},
+					Usage:   "Open an editor for the commit message",
+				},
 			},
 		},
 		{
@@ -555,6 +595,15 @@ func (s *Action) GetCommands() []*cli.Command {
 					Aliases: []string{"a"},
 					Usage:   "Append data read from STDIN to existing data",
 				},
+				&cli.StringFlag{
+					Name:  "commit-message",
+					Usage: "Set the commit message",
+				},
+				&cli.BoolFlag{
+					Name:    "interactive-commit",
+					Aliases: []string{"i"},
+					Usage:   "Open an editor for the commit message",
+				},
 			},
 		},
 		{
@@ -650,6 +699,16 @@ func (s *Action) GetCommands() []*cli.Command {
 					Aliases: []string{"f"},
 					Usage:   "Force to move the secret and overwrite existing one",
 				},
+				&cli.StringFlag{
+					Name:    "commit-message",
+					Aliases: []string{"m"},
+					Usage:   "Set the commit message",
+				},
+				&cli.BoolFlag{
+					Name:    "interactive-commit",
+					Aliases: []string{"i"},
+					Usage:   "Open an editor for the commit message",
+				},
 			},
 		},
 		{
@@ -669,7 +728,11 @@ func (s *Action) GetCommands() []*cli.Command {
 						"This command allows for mounting an existing or new password store " +
 						"at any path in an existing root store." +
 						"\n\n" +
-						"For example: gopass mounts add secondary-store /path/to/existing/store" +
+						"For example: gopass mounts add /path/to/existing/store" +
+						"\n" +
+						"This will mount the store at /path/to/existing/store with the alias 'store'." +
+						"\n\n" +
+						"Or with a custom alias: gopass mounts add secondary-store /path/to/existing/store" +
 						"\n\n" +
 						"Learn more: https://github.com/gopasspw/gopass/blob/master/docs/commands/mounts.md",
 					Before: s.IsInitialized,
@@ -717,6 +780,11 @@ func (s *Action) GetCommands() []*cli.Command {
 			Action:       s.OTP,
 			BashComplete: s.Complete,
 			Flags: []cli.Flag{
+				&cli.BoolFlag{
+					Name:    "alsoclip",
+					Aliases: []string{"C"},
+					Usage:   "Copy the time-based token and show it",
+				},
 				&cli.BoolFlag{
 					Name:    "clip",
 					Aliases: []string{"c"},
@@ -890,6 +958,18 @@ func (s *Action) GetCommands() []*cli.Command {
 				},
 			},
 		},
+		{
+			Name:      "reorg",
+			Usage:     "Reorganize a password store by editing a text file",
+			ArgsUsage: "[prefix]",
+			Description: "" +
+				"This command lists all the secrets in a text file, line by line, and then opens it in an editor. " +
+				"Once the user saves and leaves the editor, gopass will read the temp file, calculate the necessary moves and show a diff and a confirmation prompt. " +
+				"Once the user acknowledges that it will reorganize the secrets and create a meaningful commit message.",
+			Before:       s.IsInitialized,
+			Action:       s.Reorg,
+			BashComplete: s.Complete,
+		},
 		{
 			Name:  "setup",
 			Usage: "Initialize a new password store",
