@@ -2,13 +2,13 @@ package action
 
 import (
 	"bytes"
-	"context"
 	"os"
 	"strings"
 	"testing"
 
 	"github.com/fatih/color"
 	"github.com/gopasspw/gopass/internal/backend"
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/gopasspw/gopass/internal/out"
 	"github.com/gopasspw/gopass/pkg/ctxutil"
 	"github.com/gopasspw/gopass/tests/can"
@@ -20,7 +20,7 @@ import (
 func TestFsck(t *testing.T) {
 	u := gptest.NewUnitTester(t)
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithTerminal(ctx, false)
 	act, err := newMock(ctx, u.StoreDir(""))
 	require.NoError(t, err)
@@ -47,28 +47,28 @@ func TestFsck(t *testing.T) {
 	require.NoError(t, act.Fsck(gptest.CliCtx(ctx, t)))
 	output := strings.TrimSpace(buf.String())
 	assert.Contains(t, output, "Checking password store integrity ...")
-	assert.Contains(t, output, "Extra recipients on foo: [0xFEEDBEEF]")
+	assert.Contains(t, output, "extra recipients on foo: [0xFEEDBEEF]")
 	buf.Reset()
 
 	// fsck (hidden)
 	require.NoError(t, act.Fsck(gptest.CliCtx(ctxutil.WithHidden(ctx, true), t)))
 	output = strings.TrimSpace(buf.String())
 	assert.NotContains(t, output, "Checking password store integrity ...")
-	assert.NotContains(t, output, "Extra recipients on foo: [0xFEEDBEEF]")
+	assert.NotContains(t, output, "extra recipients on foo: [0xFEEDBEEF]")
 	buf.Reset()
 
 	// fsck --decrypt
 	require.NoError(t, act.Fsck(gptest.CliCtxWithFlags(ctx, t, map[string]string{"decrypt": "true"})))
 	output = strings.TrimSpace(buf.String())
 	assert.Contains(t, output, "Checking password store integrity ...")
-	assert.Contains(t, output, "Extra recipients on foo: [0xFEEDBEEF]")
+	assert.Contains(t, output, "extra recipients on foo: [0xFEEDBEEF]")
 	buf.Reset()
 
 	// fsck foo
 	require.NoError(t, act.Fsck(gptest.CliCtx(ctx, t, "foo")))
 	output = strings.TrimSpace(buf.String())
 	assert.Contains(t, output, "Checking password store integrity ...")
-	assert.Contains(t, output, "Extra recipients on foo: [0xFEEDBEEF]")
+	assert.Contains(t, output, "extra recipients on foo: [0xFEEDBEEF]")
 	buf.Reset()
 }
 
@@ -79,7 +79,7 @@ func TestFsckGpg(t *testing.T) {
 
 	u := gptest.NewGUnitTester(t)
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithTerminal(ctx, false)
 	ctx = backend.WithCryptoBackend(ctx, backend.GPGCLI)
 
