@@ -51,6 +51,16 @@ func (s *Action) Generate(c *cli.Context) error {
 		}
 	}
 
+	// Check for custom commit message
+	commitMsg := "Generated Password"
+	if c.IsSet("commit-message") {
+		commitMsg = c.String("commit-message")
+	}
+	if c.Bool("interactive-commit") {
+		commitMsg = ""
+	}
+	ctx = ctxutil.WithCommitMessage(ctx, commitMsg)
+
 	// ask for confirmation before overwriting existing entry.
 	if !force { // don't check if it's force anyway.
 		if s.Store.Exists(ctx, name) && key == "" && !termio.AskForConfirmation(ctx, fmt.Sprintf("An entry already exists for %s. Overwrite the current password?", name)) {
@@ -79,7 +89,7 @@ func (s *Action) Generate(c *cli.Context) error {
 	}
 
 	// if requested launch editor to add more data to the generated secret.
-	if edit && termio.AskForConfirmation(ctx, fmt.Sprintf("Do you want to add more data for %s?", name)) {
+	if edit {
 		c.Context = ctx
 		if err := s.Edit(c); err != nil {
 			return exit.Error(exit.Unknown, err, "failed to edit %q: %s", name, err)
@@ -152,7 +162,11 @@ func (s *Action) generateCopyOrPrint(ctx context.Context, c *cli.Context, name,
 	return nil
 }
 
+// hasRuleForSecret extracts the domain from the secret name and checks if there is a
+// password rule for it. If so, it returns the domain and the rule. If the domain is
+// empty no rule is found.
 func hasPwRuleForSecret(ctx context.Context, name string) (string, pwrules.Rule) {
+	// trim elements from the end of the path until we find a domain or the root.
 	for name != "" && name != "." {
 		d := path.Base(name)
 		if r, found := pwrules.LookupRule(ctx, d); found {
@@ -167,20 +181,11 @@ func hasPwRuleForSecret(ctx context.Context, name string) (string, pwrules.Rule)
 // generatePassword will run through the password generation steps.
 func (s *Action) generatePassword(ctx context.Context, c *cli.Context, length, name string) (string, error) {
 	if domain, rule := hasPwRuleForSecret(ctx, name); domain != "" && !c.Bool("force") {
-		return s.generatePasswordForRule(ctx, c, length, name, domain, rule)
+		return s.generatePasswordForRule(ctx, length, domain, rule)
 	}
 
 	cfg, mp := config.FromContext(ctx)
 
-	symbols := false
-	if c.IsSet("symbols") {
-		symbols = c.Bool("symbols")
-	} else {
-		if cfg.GetM(mp, "generate.symbols") != "" {
-			symbols = config.AsBool(cfg.GetM(mp, "generate.symbols"))
-		}
-	}
-
 	generator := cfg.GetM(mp, "generate.generator")
 	if c.IsSet("generator") {
 		generator = c.String("generator")
@@ -190,6 +195,15 @@ func (s *Action) generatePassword(ctx context.Context, c *cli.Context, length, n
 		return s.generatePasswordXKCD(ctx, c, length)
 	}
 
+	symbols := false
+	if c.IsSet("symbols") {
+		symbols = c.Bool("symbols")
+	} else {
+		if cfg.GetM(mp, "generate.symbols") != "" {
+			symbols = config.AsBool(cfg.GetM(mp, "generate.symbols"))
+		}
+	}
+
 	var pwlen int
 	if length == "" {
 		pwlength, err := getPwLengthFromEnvOrAskUser(ctx)
@@ -249,34 +263,39 @@ func getPwLengthFromEnvOrAskUser(ctx context.Context) (int, error) {
 	return pwlen, nil
 }
 
-func clamp(min, max, value int) int {
-	if value < min {
-		return min
-	}
-
-	if value > max && max > 0 {
-		return max
-	}
-
-	return value
-}
-
-func (s *Action) generatePasswordForRule(ctx context.Context, c *cli.Context, length, name, domain string, rule pwrules.Rule) (string, error) {
+// generatePasswordForRule validates the user-provided password length against
+// the rule for the domain and condtionally prompts the user for a correct
+// length if the initial value is invalid.
+func (s *Action) generatePasswordForRule(ctx context.Context, length, domain string, rule pwrules.Rule) (string, error) {
 	out.Noticef(ctx, "Using password rules for %s ...", domain)
 
-	wl := 16
-	if iv, err := strconv.Atoi(length); err == nil {
-		wl = clamp(rule.Minlen, rule.Maxlen, iv)
-		debug.Log("restricting requested password length (%s) to %d because of the rule {%d,%d}", length, wl, rule.Minlen, rule.Maxlen)
-	}
+	var iv int
+	var err error
 
-	question := fmt.Sprintf("How long should the password be? (min: %d, max: %d)", rule.Minlen, rule.Maxlen)
-	iv, err := termio.AskForInt(ctx, question, wl)
-	if err != nil {
+	if iv, err = strconv.Atoi(length); err != nil {
 		return "", exit.Error(exit.Usage, err, "password length must be a number")
 	}
 
-	iv = clamp(rule.Minlen, rule.Maxlen, iv)
+	if iv < rule.Minlen || iv > rule.Maxlen {
+		debug.Log(
+			"pw length %s does not match rule {min: %d, max: %d}, prompting for another one",
+			length, rule.Minlen, rule.Maxlen,
+		)
+
+		question := fmt.Sprintf(
+			"How long should the password be? (min: %d, max: %d)",
+			rule.Minlen, rule.Maxlen,
+		)
+
+		var sv string
+
+		if sv, err = termio.AskForString(ctx, question, strconv.Itoa(rule.Maxlen)); err != nil {
+			return "", err
+		}
+
+		// recursively prompt the user until a valid length is provided
+		return s.generatePasswordForRule(ctx, sv, domain, rule)
+	}
 
 	pw := pwgen.NewCrypticForDomain(ctx, iv, domain).Password()
 	if pw == "" {
@@ -345,7 +364,7 @@ func (s *Action) generateSetPassword(ctx context.Context, name, key, password st
 
 		setMetadata(sec, kvps)
 		_ = sec.Set(key, password)
-		if err := s.Store.Set(ctxutil.WithCommitMessage(ctx, "Generated password for key"), name, sec); err != nil {
+		if err := s.Store.Set(ctx, name, sec); err != nil {
 			if !errors.Is(err, store.ErrMeaninglessWrite) {
 				return ctx, exit.Error(exit.Encrypt, err, "failed to set key %q of %q: %s", key, name, err)
 			}
@@ -383,7 +402,7 @@ func (s *Action) generateSetPassword(ctx context.Context, name, key, password st
 		}
 	}
 
-	if err := s.Store.Set(ctxutil.WithCommitMessage(ctx, "Generated Password"), name, sec); err != nil {
+	if err := s.Store.Set(ctx, name, sec); err != nil {
 		if !errors.Is(err, store.ErrMeaninglessWrite) {
 			return ctx, exit.Error(exit.Encrypt, err, "failed to create %q: %s", name, err)
 		}
@@ -412,7 +431,7 @@ func (s *Action) generateReplaceExisting(ctx context.Context, name, key, passwor
 
 	setMetadata(sec, kvps)
 	sec.SetPassword(password)
-	if err := s.Store.Set(ctxutil.WithCommitMessage(ctx, "Generated password for YAML key"), name, sec); err != nil {
+	if err := s.Store.Set(ctx, name, sec); err != nil {
 		if !errors.Is(err, store.ErrMeaninglessWrite) {
 			return ctx, exit.Error(exit.Encrypt, err, "failed to set key %q of %q: %s", key, name, err)
 		}
