@@ -4,6 +4,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"slices"
 	"strconv"
 	"strings"
 
@@ -36,6 +37,9 @@ func showParseArgs(c *cli.Context) context.Context {
 	if c.IsSet("qr") {
 		ctx = WithPrintQR(ctx, c.Bool("qr"))
 	}
+	if c.IsSet("qrbody") {
+		ctx = WithQRBody(ctx, c.Bool("qrbody"))
+	}
 
 	if c.IsSet("password") {
 		ctx = WithPasswordOnly(ctx, c.Bool("password"))
@@ -45,6 +49,7 @@ func showParseArgs(c *cli.Context) context.Context {
 		ctx = WithRevision(ctx, c.String("revision"))
 	}
 
+	ctx = WithAlsoClip(ctx, config.Bool(ctx, "show.autoclip"))
 	if c.IsSet("alsoclip") {
 		ctx = WithAlsoClip(ctx, c.Bool("alsoclip"))
 	}
@@ -55,7 +60,7 @@ func showParseArgs(c *cli.Context) context.Context {
 
 	if c.IsSet("chars") {
 		iv := []int{}
-		for _, v := range strings.Split(c.String("chars"), ",") {
+		for v := range strings.SplitSeq(c.String("chars"), ",") {
 			v = strings.TrimSpace(v)
 			if v == "" {
 				continue
@@ -194,16 +199,23 @@ func (s *Action) showHandleOutput(ctx context.Context, name string, sec gopass.S
 			out.Warning(ctx, "show.safecontent=true. Use -f to display password, if any")
 		}
 
-		return exit.Error(exit.NotFound, store.ErrEmptySecret, store.ErrEmptySecret.Error())
+		return exit.Error(exit.NotFound, store.ErrEmptySecret, "%v", store.ErrEmptySecret)
 	}
 
+	if IsPrintQR(ctx) && IsQRBody(ctx) {
+		if err := s.showPrintQR(name, body); err != nil {
+			return err
+		}
+
+		return nil
+	}
 	if IsPrintQR(ctx) && pw != "" {
 		if err := s.showPrintQR(name, pw); err != nil {
 			return err
 		}
 	}
 
-	if (IsClip(ctx) || config.Bool(ctx, "show.autoclip")) && pw != "" {
+	if (IsClip(ctx) || IsAlsoClip(ctx)) && pw != "" {
 		if err := clipboard.CopyTo(ctx, name, []byte(pw), config.AsInt(s.cfg.Get("core.cliptimeout"))); err != nil {
 			return err
 		}
@@ -213,6 +225,11 @@ func (s *Action) showHandleOutput(ctx context.Context, name string, sec gopass.S
 		return nil
 	}
 
+	// do not output when the clip flag is set
+	if IsOnlyClip(ctx) {
+		return nil
+	}
+
 	ctx = out.WithNewline(ctx, ctxutil.IsTerminal(ctx))
 	if ctxutil.IsTerminal(ctx) && !IsPasswordOnly(ctx) {
 		header := fmt.Sprintf("Secret: %s\n", name)
@@ -234,7 +251,7 @@ func (s *Action) showGetContent(ctx context.Context, sec gopass.Secret) (string,
 		key := GetKey(ctx)
 		values, found := sec.Values(key)
 		if !found {
-			return "", "", exit.Error(exit.NotFound, store.ErrNoKey, store.ErrNoKey.Error())
+			return "", "", exit.Error(exit.NotFound, store.ErrNoKey, "%v", store.ErrNoKey)
 		}
 		val := strings.Join(values, "\n")
 
@@ -245,13 +262,16 @@ func (s *Action) showGetContent(ctx context.Context, sec gopass.Secret) (string,
 	// fallback for old MIME secrets.
 	fullBody := strings.TrimPrefix(string(sec.Bytes()), secrets.Ident+"\n")
 
+	if IsQRBody(ctx) {
+		return pw, fullBody, nil
+	}
 	// first line of the secret only.
 	if IsPrintQR(ctx) || IsOnlyClip(ctx) {
 		return pw, "", nil
 	}
 	if IsPasswordOnly(ctx) {
 		if pw == "" && fullBody != "" {
-			return "", "", exit.Error(exit.NotFound, store.ErrNoPassword, store.ErrNoPassword.Error())
+			return "", "", exit.Error(exit.NotFound, store.ErrNoPassword, "%v", store.ErrNoPassword)
 		}
 
 		return pw, pw, nil
@@ -293,13 +313,21 @@ func showSafeContent(sec gopass.Secret) string {
 		}
 	}
 
-	sb.WriteString(sec.Body())
+	for _, l := range strings.Split(sec.Body(), "\n") {
+		if strings.HasPrefix(l, "otpauth://") {
+			sb.WriteString(fmt.Sprintf("\notpauth://%s", randAsterisk()))
+
+			continue
+		}
+		sb.WriteString(l)
+	}
 
 	return sb.String()
 }
 
 func isUnsafeKey(key string, sec gopass.Secret) bool {
-	if strings.ToLower(key) == "password" {
+	duks := []string{"hotp", "otpauth", "password", "totp"}
+	if slices.Contains(duks, key) {
 		return true
 	}
 
