@@ -53,7 +53,7 @@ func (s *Action) checkVersion(ctx context.Context, u chan string) {
 	}
 
 	// NB: "updater.check" isn't supported as a local config option, hence no mount point here
-	if cfg, _ := config.FromContext(ctx); cfg.IsSet("updater.check") && !cfg.GetBool("updater.check") {
+	if cfg, _ := config.FromContext(ctx); cfg.IsSet("updater.check") && !config.AsBool(cfg.Get("updater.check")) {
 		debug.Log("remote version check disabled by updater.check = false")
 
 		return
@@ -84,7 +84,7 @@ func (s *Action) checkVersion(ctx context.Context, u chan string) {
 		return
 	}
 
-	if s.version.GTE(r.Version) {
+	if r.Version.GT(s.version) {
 		_ = s.rem.Reset("update")
 		debug.Log("gopass is up-to-date (local: %q, GitHub: %q)", s.version, r.Version)
 
