@@ -1,5 +1,4 @@
 //go:build linux
-// +build linux
 
 package gpgconf
 
@@ -13,5 +12,5 @@ func TestTTY(t *testing.T) {
 	t.Parallel()
 
 	fd0 = "/tmp/foobar"
-	assert.Equal(t, "", TTY())
+	assert.Empty(t, TTY())
 }
