@@ -1,11 +1,11 @@
 package leaf
 
 import (
-	"context"
 	"testing"
 
 	"github.com/fatih/color"
 	"github.com/gopasspw/gopass/internal/backend"
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -13,7 +13,7 @@ import (
 func TestTemplates(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	tempdir := t.TempDir()
 
@@ -22,8 +22,10 @@ func TestTemplates(t *testing.T) {
 	_, _, err := createStore(tempdir, nil, nil)
 	require.NoError(t, err)
 
-	ctx = backend.WithCryptoBackendString(ctx, "plain")
-	ctx = backend.WithStorageBackendString(ctx, "fs")
+	ctx, err = backend.WithCryptoBackendString(ctx, "plain")
+	require.NoError(t, err)
+	ctx, err = backend.WithStorageBackendString(ctx, "fs")
+	require.NoError(t, err)
 	s, err := New(
 		ctx,
 		"",
