@@ -1,5 +1,4 @@
 //go:build !windows
-// +build !windows
 
 package pwgen
 
@@ -7,6 +6,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestPwgenExternal(t *testing.T) {
@@ -14,6 +14,6 @@ func TestPwgenExternal(t *testing.T) {
 
 	pw, err := GenerateExternal(4)
 
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "foobar 4", pw)
 }
