@@ -14,11 +14,11 @@ func getVersion() semver.Version {
 
 	return semver.Version{
 		Major: 1,
-		Minor: 15,
-		Patch: 11,
+		Minor: 16,
+		Patch: 0,
 		Pre: []semver.PRVersion{
 			{VersionStr: "git"},
 		},
-		Build: []string{"HEAD"},
+		Build: []string{"423333db"},
 	}
 }
